@@ -82,6 +82,7 @@ repos = OrderedDict({
         'cloudmesh-azure',
         'cloudmesh-aws',
         'cloudmesh-openstack',
+        'cloudmesh-chameleon',
         'cloudmesh-google',
         'cloudmesh-oracle',
         'cloudmesh-storage',
@@ -96,6 +97,10 @@ repos = OrderedDict({
         'cloudmesh-javascript'
     ],
 
+    'job': cloud + [
+        'cloudmesh-job'
+    ],
+
     'gui': cloud + [
         'cloudmesh-admin',
         'cloudmesh-gui'
@@ -141,10 +146,6 @@ repos = OrderedDict({
         'cloudmesh-kubernetes'
     ],
 
-    'kubernetesd': ['cloudmesh-cmsd',
-                   'cloudmesh-docker',
-                   'cloudmesh-kubernetes'],
-
     'volume': cms + cloud + [
         'cloudmesh-admin',
         'cloudmesh-gui',
@@ -178,7 +179,6 @@ repos = OrderedDict({
     'docker-command': ['cloudmesh-cmsd',
                        'cloudmesh-docker'],
 
-
     'iu': cms + cloud + [   # add cloud so the yaml file gets created
         'cloudmesh-iu',
         # cloudmesh-notebook
@@ -207,7 +207,8 @@ repos = OrderedDict({
     ],
 
     'openstack': cloud + [
-        'cloudmesh-openstack'
+        'cloudmesh-openstack',
+        'cloudmesh-chameleon'
     ],
 
     'google': cloud + [
@@ -219,6 +220,7 @@ repos = OrderedDict({
         'cloudmesh-azure',
         'cloudmesh-aws',
         'cloudmesh-openstack',
+        'cloudmesh-chameleon',
         'cloudmesh-google',
         'cloudmesh-oracle',
         'cloudmesh-multipass'
@@ -228,6 +230,7 @@ repos = OrderedDict({
         'cloudmesh-azure',
         'cloudmesh-aws',
         'cloudmesh-openstack',
+        'cloudmesh-chameleon',
         'cloudmesh-google',
         'cloudmesh-oracle',
         'cloudmesh-multipass'
@@ -259,8 +262,6 @@ repos = OrderedDict({
         'cloudmesh-batch',
         'cloudmesh-box',
         'cloudmesh-cmsd',
-        'cloudmesh-comet',
-        'cloudmesh-conda',
         'cloudmesh-docker',
         'cloudmesh-emr',
         'cloudmesh-flow',
@@ -287,6 +288,11 @@ repos = OrderedDict({
         'cloudmesh-installer'
     ],
 
+    'deprecated': [
+        'cloudmesh-comet',
+        'cloudmesh-conda'
+    ],
+
     'web': [
         'about',
         'get',
